// Dataset (replace with your actual dataset)
var data = [
  { Country: 'USA', SalesAmount: 5000 },
  { Country: 'UK', SalesAmount: 7000 },
  { Country: 'Canada', SalesAmount: 3000 },
  // Add more data for other countries
];

// Set up SVG dimensions
var svgWidth = 600;
var svgHeight = 400;

// Set up margin
var margin = { top: 20, right: 20, bottom: 30, left: 40 };
var width = svgWidth - margin.left - margin.right;
var height = svgHeight - margin.top - margin.bottom;

// Create SVG element
var svg = d3
  .select('#chart')
  .append('svg')
  .attr('width', svgWidth)
  .attr('height', svgHeight)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

// Create x and y scales
var xScale = d3.scaleBand().range([0, width]).padding(0.1);
var yScale = d3.scaleLinear().range([height, 0]);

// Set domain for x and y scales
xScale.domain(
  data.map(function (d) {
    return d.Country;
  }),
);
yScale.domain([
  0,
  d3.max(data, function (d) {
    return d.SalesAmount;
  }),
]);

// Create x and y axes
var xAxis = d3.axisBottom(xScale);
var yAxis = d3.axisLeft(yScale);

// Add x-axis
svg
  .append('g')
  .attr('class', 'x axis')
  .attr('transform', 'translate(0,' + height + ')')
  .call(xAxis);

// Add y-axis
svg.append('g').attr('class', 'y axis').call(yAxis);

// Add bars
svg
  .selectAll('.bar')
  .data(data)
  .enter()
  .append('rect')
  .attr('class', 'bar')
  .attr('x', function (d) {
    return xScale(d.Country);
  })
  .attr('width', xScale.bandwidth())
  .attr('y', function (d) {
    return yScale(d.SalesAmount);
  })
  .attr('height', function (d) {
    return height - yScale(d.SalesAmount);
  });
